#******************************************************************************
#
# Project ICI-Covid
#
# Obj: Descriptive statistics: Who provides informal care, depending on family situation 
#       (Table 2 of the article)
#
# Authors: Lucas Jeanneau - Quitterie Roquebert - Marianne Tenand
#
# Last modified: 10/03/2021
#
#******************************************************************************

  # Beforehand: run 0.Data.R

#### Packages for the program ####
# NB : for first run, need to do "install.packages(NAMEOFTHEPACKAGE)" first
# Then, run library(PACKAGE) at each opening of R
library(dplyr)
library(questionr) 

#### Prepare data ####

# Merge information on caregivers to the respondent dataset
lien<-merge(seniors,aidants, by="idsenior")

# Drop all caregivers who do not provide help for ADL/IADL
lien2<-subset(lien, ahentvq_c==1) 

detach
attach(lien2)

# For each respondent who has a caregiver, count the number of each type of caregiver she has
  # Variable liensenaid gives the relationship between the respondent and the caregiver 
tab<-table(idsenior,liensenaid)
tab<-as.data.frame.matrix(tab)

# Reformat so that the respondent ID becomes a column 
t<- tibble::rownames_to_column(tab, "idsenior")

# Link with the respondent dataset 
t2<-left_join(seniors,t, by= "idsenior")

detach(lien2)
attach(t2)

t2$`1`[is.na(t2$`1`)]<-0
t2$`2`[is.na(t2$`2`)]<-0
t2$`2`[is.na(t2$`2`)]<-0
t2$`3`[is.na(t2$`3`)]<-0
t2$`4`[is.na(t2$`4`)]<-0
t2$`5`[is.na(t2$`5`)]<-0
t2$`6`[is.na(t2$`6`)]<-0
t2$`7`[is.na(t2$`7`)]<-0
t2$`8`[is.na(t2$`8`)]<-0
t2$`9`[is.na(t2$`9`)]<-0
t2$`10`[is.na(t2$`10`)]<-0
t2$`12`[is.na(t2$`12`)]<-0

detach(t2)
attach(t2)

# Create subset for 3 groups, defined by presence of partner and/or children

partner<-tccouple
partner[partner==9]<-0

nbchildren<-tcenf
child<-ifelse(nbchildren!=0,1,0)
child[is.na(child)]=0

df_have_partner<-subset(t2, partner!=0)
df_child_no_partner<-subset(t2,partner==0 & child!=0)
df_no_child_no_partner<-subset(t2,partner==0 & child==0)


#### Create dataframe ####

  # For each subset, compute the proportion of respondents that receive help from a certain category of individuals 

# Individuals with a partner

detach(t2)
attach(df_have_partner)

poidsen<-as.numeric(poids_senior)

child_or_partner<-ifelse(`1`!=0 | `3`!=0,1,0) 
brother_sister_father_mother<- ifelse(`2`!=0| `4`!=0,1,0)
other_member_of_the_family<-ifelse(`8`!=0 |`5`!=0 | `6`!=0 |`7`!=0 ,1,0)
friend_or_other_resident<-ifelse(`9`!=0| `12`!=0,1,0)
somebody_else<-ifelse(`10`!=0 | `99`!=0,1,0)
nobody<- ifelse(`1`==0 &`2`==0 &`3`==0 &`4`==0 &`5`==0 &`6`==0 &`7`==0 &`8`==0 &`9`==0 &`10`==0 &`12`==0 ,1,0)
nobody[is.na(nobody)]<-1

v1<- as.vector(prop.table(wtd.table(child_or_partner, weights = poidsen)))
v2<- as.vector(prop.table(wtd.table(brother_sister_father_mother, weights = poidsen)))
v3<- as.vector(prop.table(wtd.table(other_member_of_the_family, weights = poidsen)))
v4<- as.vector(prop.table(wtd.table(friend_or_other_resident, weights = poidsen)))
v5<- as.vector(prop.table(wtd.table(somebody_else, weights = poidsen)))
v6<- as.vector(prop.table(wtd.table(nobody, weights = poidsen)))

# Individuals with no partner but children

detach(df_have_partner)
attach(df_child_no_partner)

poidsen<-as.numeric(poids_senior)

child_or_partner<-ifelse(`1`!=0 | `3`!=0,1,0) 
brother_sister_father_mother<- ifelse(`2`!=0| `4`!=0,1,0)
other_member_of_the_family<-ifelse(`8`!=0 |`5`!=0 | `6`!=0 |`7`!=0 ,1,0)
friend_or_other_resident<-ifelse(`9`!=0| `12`!=0,1,0)
somebody_else<-ifelse(`10`!=0 | `99`!=0,1,0)
nobody<- ifelse(`1`==0 &`2`==0 &`3`==0 &`4`==0 &`5`==0 &`6`==0 &`7`==0 &`8`==0 &`9`==0 &`10`==0 &`12`==0 ,1,0)
nobody[is.na(nobody)]<-1

v7<- as.vector(prop.table(wtd.table(child_or_partner, weights = poidsen)))
v8<- as.vector(prop.table(wtd.table(brother_sister_father_mother, weights = poidsen)))
v9<- as.vector(prop.table(wtd.table(other_member_of_the_family, weights = poidsen)))
v10<- as.vector(prop.table(wtd.table(friend_or_other_resident, weights = poidsen)))
v11<- as.vector(prop.table(wtd.table(somebody_else, weights = poidsen)))
v12<- as.vector(prop.table(wtd.table(nobody, weights = poidsen)))

# Individuals with no partner and no children

detach(df_child_no_partner)
attach(df_no_child_no_partner)

poidsen<-as.numeric(poids_senior)

child_or_partner<- ifelse(`2`==3,1,0) # We constrain it to be 0
  # Some respondents declare being helped by their children or their partner,
  # while they do not have any according to the information provided in the survey.
  # We recode them as receiving help from another family member, which they might consider
  # as their child or partner
brother_sister_father_mother<- ifelse(`2`!=0| `4`!=0,1,0) 
other_member_of_the_family<-ifelse(`1`!=0 | `3`!=0 | `8`!=0 |`5`!=0 | `6`!=0 |`7`!=0 ,1,0)
friend_or_other_resident<-ifelse(`9`!=0| `12`!=0,1,0)
somebody_else<-ifelse(`10`!=0 | `99`!=0,1,0)
nobody<- ifelse(`1`==0 &`2`==0 &`3`==0 &`4`==0 &`5`==0 &`6`==0 &`7`==0 &`8`==0 &`9`==0 &`10`==0 &`12`==0 ,1,0)
nobody[is.na(nobody)]<-1

v13<- as.vector(prop.table(wtd.table(child_or_partner, weights = poidsen)))
v14<- as.vector(prop.table(wtd.table(brother_sister_father_mother, weights = poidsen)))
v15<- as.vector(prop.table(wtd.table(other_member_of_the_family, weights = poidsen)))
v16<- as.vector(prop.table(wtd.table(friend_or_other_resident, weights = poidsen)))
v17<- as.vector(prop.table(wtd.table(somebody_else, weights = poidsen)))
v18<- as.vector(prop.table(wtd.table(nobody, weights = poidsen)))


#### Create the table of conditional probabilities ####

first_column <- c(v1[2],v2[2],v3[2],v4[2],v5[2],v6[2])
second_column<- c(v7[2],v8[2],v9[2],v10[2],v11[2],v12[2])
third_column<- c(v13[2],v14[2],v15[2],v16[2],v17[2],v18[2])

dataframe_help<- data.frame(first_column,second_column,third_column)

row.names(dataframe_help)= c("Helped by child or partner","Helped by siblings or parents","Helped by other family member", "Helped by friend or other resident", "Helped by somebody else", "No informal care with ADL/IADL")

colnames(dataframe_help) = c("Has a partner", "Has children but no partner","Has neither children nor a partner")

## export to csv file

write.csv2(dataframe_help, file = paste0(dropbox, out_DS ,"Covid_NH_Table2_Family_Configurations.csv"))

